---
name: "🐞 Issue report for jwst-pure-parallel"
about: Create a report describing unexpected or incorrect behavior
title: "[ISSUE]: "
labels: bug
assignees: 'JeffValenti'
---

<!--
Thanks for taking the time to fill out this report!
Please have a search on our repository to see if a similar
issue has already been posted. If a similar issue is closed, have a
quick look to see if you are satisfied by the resolution.

If not please go ahead and open an issue!
-->

### Current Behavior:
<!-- A concise description of what you're experiencing. -->

### Expected Behavior:
<!-- A concise description of what you expected to happen. -->

### Steps To Reproduce:
<!--
Example: steps to reproduce the behavior:
1. In this environment...
1. With this config...
1. Run '...'
1. See error...
-->

### Environment:
<!--
Example:
- OS: Ubuntu 20.04
- astropy: 7.0
- python: 3.13
- numpy: 2.0
-->

### Anything else:
<!--
Links? References? Anything that will give us more context about the issue that you are encountering!
-->
